==> puppet-module-keystone_19.4.0.orig.tar.xz: puppet-module-keystone-19.4.0/spec/unit/type/keystone_uwsgi_config_spec.rb <==
require 'puppet'
require 'puppet/type/keystone_uwsgi_config'

describe 'Puppet::Type.type(:keystone_uwsgi_config)' do
  before :each do
    @keystone_uwsgi_config = Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'DEFAULT/foo', :value => 'bar')
  end

 it 'should require a name' do
    expect {
      Puppet::Type.type(:keystone_uwsgi_config).new({})
    }.to raise_error(Puppet::Error, 'Title or name must be provided')
  end

  it 'should not expect a name with whitespace' do
    expect {
      Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'f oo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should fail when there is no section' do
    expect {
      Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'foo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should not require a value when ensure is absent' do
    Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'DEFAULT/foo', :ensure => :absent)
  end

  it 'should accept a valid value' do
    @keystone_uwsgi_config[:value] = 'bar'
    expect(@keystone_uwsgi_config[:value]).to eq('bar')
  end

  it 'should not accept a value with whitespace' do
    @keystone_uwsgi_config[:value] = 'b ar'
    expect(@keystone_uwsgi_config[:value]).to eq('b ar')
  end

  it 'should accept valid ensure values' do
    @keystone_uwsgi_config[:ensure] = :present
    expect(@keystone_uwsgi_config[:ensure]).to eq(:present)
    @keystone_uwsgi_config[:ensure] = :absent
    expect(@keystone_uwsgi_config[:ensure]).to eq(:absent)
  end

  it 'should not accept invalid ensure values' do
    expect {
      @keystone_uwsgi_config[:ensure] = :latest
    }.to raise_error(Puppet::Error, /Invalid value/)
  end

  it 'should autorequire the package that install the file' do
    catalog = Puppet::Resource::Catalog.new
    anchor = Puppet::Type.type(:anchor).new(:name => 'keystone::install::end')
    catalog.add_resource anchor, @keystone_uwsgi_config
    dependency = @keystone_uwsgi_config.autorequire
    expect(dependency.size).to eq(1)
    expect(dependency[0].target).to eq(@keystone_uwsgi_config)
    expect(dependency[0].source).to eq(anchor)
  end

end

==> puppet-module-keystone_25.0.0.orig.tar.xz: puppet-module-keystone-25.0.0/spec/unit/type/keystone_uwsgi_config_spec.rb <==
require 'puppet'
require 'puppet/type/keystone_uwsgi_config'

describe 'Puppet::Type.type(:keystone_uwsgi_config)' do
  before :each do
    @keystone_uwsgi_config = Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'DEFAULT/foo', :value => 'bar')
  end

 it 'should require a name' do
    expect {
      Puppet::Type.type(:keystone_uwsgi_config).new({})
    }.to raise_error(Puppet::Error, 'Title or name must be provided')
  end

  it 'should not expect a name with whitespace' do
    expect {
      Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'f oo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should fail when there is no section' do
    expect {
      Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'foo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should not require a value when ensure is absent' do
    Puppet::Type.type(:keystone_uwsgi_config).new(:name => 'DEFAULT/foo', :ensure => :absent)
  end

  it 'should accept a valid value' do
    @keystone_uwsgi_config[:value] = 'bar'
    expect(@keystone_uwsgi_config[:value]).to eq('bar')
  end

  it 'should accept a value with whitespace' do
    @keystone_uwsgi_config[:value] = 'b ar'
    expect(@keystone_uwsgi_config[:value]).to eq('b ar')
  end

  it 'should accept valid ensure values' do
    @keystone_uwsgi_config[:ensure] = :present
    expect(@keystone_uwsgi_config[:ensure]).to eq(:present)
    @keystone_uwsgi_config[:ensure] = :absent
    expect(@keystone_uwsgi_config[:ensure]).to eq(:absent)
  end

  it 'should not accept invalid ensure values' do
    expect {
      @keystone_uwsgi_config[:ensure] = :latest
    }.to raise_error(Puppet::Error, /Invalid value/)
  end

  it 'should autorequire the package that install the file' do
    catalog = Puppet::Resource::Catalog.new
    anchor = Puppet::Type.type(:anchor).new(:name => 'keystone::install::end')
    catalog.add_resource anchor, @keystone_uwsgi_config
    dependency = @keystone_uwsgi_config.autorequire
    expect(dependency.size).to eq(1)
    expect(dependency[0].target).to eq(@keystone_uwsgi_config)
    expect(dependency[0].source).to eq(anchor)
  end

end
